@@ -5,7 +5,7 @@ TODO
 """
 
 from .data_util import *  # noqa
-from .fits2caom2 import *  # noqa
+from .caom2blueprint import *  # noqa
 from .legacy import *  # noqa
 from .wcs_util import * # noqa
 from .wcsvalidator import * # noqa
